Deposit bundle (alpha) — Invenio 3.4.0a8 documentation

# Deposit bundle (alpha)

Note

This bundle is in alpha. The modules are being used in production systems but are very likely subject to change.

Warning

All modules on this page will be discontinued, as they are some significant design issues in them.

Included modules:

- invenio-deposit

    - REST API for managing deposit of records into Invenio with support for in progress editing of records.

- invenio-files-js

    - AngularJS application for uploading files to Invenio via streaming the binary files in an HTTP request.

- invenio-records-js

    - AngularJS application for interacting with the deposit REST API and rendering forms based on angular schema forms.

- invenio-sipstore

    - Submission Information Package (SIP) store with bagit support.